package com.muyu.cloud.common.many.datasource.role;

import com.alibaba.druid.pool.DruidDataSource;
import com.muyu.cloud.common.many.datasource.holder.DynamicDataSourceHolder;
import lombok.AllArgsConstructor;
import lombok.Data;
import lombok.EqualsAndHashCode;
import lombok.NoArgsConstructor;
import org.springframework.jdbc.datasource.lookup.AbstractRoutingDataSource;

import java.util.Map;

/**
 * 动态数据源
 * 调用AddDefineDataSource组件的addDefineDynamicDataSource（）方法，获取原来targetdatasources的map，并将新的数据源信息添加到map中，并替换targetdatasources中的map
 * 切换数据源时可以使用@DataSource(value = "数据源名称")，或者DynamicDataSourceContextHolder.setContextKey("数据源名称")
 * @author Dongzl
 */
@EqualsAndHashCode(callSuper = true)
@Data
@AllArgsConstructor
@NoArgsConstructor
public class DynamicDataSource extends AbstractRoutingDataSource {
    /**
     * 备份所有数据源信息
     */
    private Map<Object, Object> defineTargetDataSources;

    /**
     *
     * @param key 键
     * @return 存在结果 true存在 false不存在
     */
    public boolean hashKey(String key){
        return defineTargetDataSources.containsKey(key);
    }

    /**
     * 添加数据库
     * @param key 键
     * @param value 数据源
     */
    public void put(String  key, DruidDataSource value) {
        defineTargetDataSources.put(key, value);
        this.afterPropertiesSet();
    }

    /**
     * 决定当前线程使用哪个数据源
     */
    @Override
    protected Object determineCurrentLookupKey() {
        return DynamicDataSourceHolder.getDynamicDataSourceKey();
    }
}
