package com.muyu.car.controller;

import com.github.pagehelper.PageInfo;
import com.muyu.car.domain.CarInformation;
import com.muyu.car.domain.CarMessage;
import com.muyu.car.domain.req.CarInformationAddReq;
import com.muyu.car.domain.req.CarInformationListReq;
import com.muyu.car.domain.req.CarInformationUpdReq;
import com.muyu.car.service.CarInformationService;
import com.muyu.common.core.domain.Result;
import io.swagger.v3.oas.annotations.Operation;
import io.swagger.v3.oas.annotations.tags.Tag;
import lombok.extern.log4j.Log4j2;
import org.springframework.stereotype.Controller;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.context.annotation.RequestScope;

import javax.annotation.Resource;
import java.util.List;


@Log4j2
@RestController
@RequestMapping("/carinformation")
@Tag(name = "车辆信息管理控制层" ,description = "进行车辆管理基础业务操作")
public class CarInformationController {
    @Resource
    private CarInformationService carInformationService;

    /**
     * 企业车辆管理列表
     * 联查--> 车辆管理--车辆类型表--车辆电子围栏
     * 搜索-->(车辆唯一VIN carInformationVIN 精确查
     * 车辆类型ID  carTypeId  精确查
     * 车辆电子围栏外键ID carInformationFence 精确查
     * 启用状态(1.在线 2.离线 3.已断开 4.待连接 5.维修中)
     * carInformationState  精确查
     * 车辆电机厂商 carInformationMotorManufacturer 模糊查
     * 车辆电机型号 carInformationMotorModel 精确查
     * 车辆电池厂商 carInformationBatteryManufacturer 模糊查
     * 车辆电池型号 carInformationBatteryModel 精确查
     * )
     * 分页-->  分页页数 pageNum  分页条数 pageSize
     *
     * @param carInformationListReq
     * @return
     */
    @PostMapping("/selectCarInformationList")
    @Operation(summary = "企业车辆管理列表")
    public Result<PageInfo<CarInformation>> selectCarInformationList(@Validated @RequestBody CarInformationListReq carInformationListReq) {
        PageInfo<CarInformation> pageInfo = carInformationService.selectCarInformationList(carInformationListReq);
        log.info("企业车辆管理列表查询",carInformationListReq,pageInfo);
        return Result.success(pageInfo);

    }


    /**
     * 企业车辆添加管理
     * @param carInformationAddReq
     * @return
     */
    @PostMapping("/addCarInformation")
    @Operation(summary = "企业车辆添加管理")
    public Result addCarInformation(@Validated @RequestBody CarInformationAddReq carInformationAddReq){
        return carInformationService.addCarInformation(carInformationAddReq);
    }

    /**
     * 企业车辆删除
     * @param carInformationId
     * @return
     */
    @GetMapping("/delBycarInformationId/{carInformationId}")
    @Operation(summary = "企业车辆删除")
    public Result delBycarInformationId(@Validated @PathVariable("carInformationId") Integer carInformationId){
        return carInformationService.delBycarInformationId(carInformationId);
    }


    /**
     * 企业车辆修改管理
     * @param carInformationUpdReq
     * @return
     */
    @PostMapping("/updatecarInformation")
    @Operation(summary = "企业车辆修改管理")
    public Result updateCarMessage(@Validated @RequestBody CarInformationUpdReq carInformationUpdReq){
        Result updatecarInformation = carInformationService.updatecarInformation(carInformationUpdReq);
        log.info(updatecarInformation);
        System.out.println("我在这个里:"+updatecarInformation);

        return Result.success(updatecarInformation,"修改成功");

    }



    /**
     * To 电子围栏负责人
     * 查询企业车辆 carInformationID 和  carInformationLicensePlate
     * 无参
     * @return
     */
    @GetMapping("/selectCarInformationIdAndLicensePlate")
    @Operation(summary = "查询企业车辆 carInformationID 和  carInformationLicensePlate")
    public Result<List<CarInformation>> selectCarInformationIdAndLicensePlate(){
        List<CarInformation> carInformations = carInformationService.selectBycarInformationIDAndLicensePlate();
        return Result.success(carInformations);
    }




}
