package com.muyu.car.controller;

import com.alibaba.fastjson.JSONObject;
import com.muyu.car.domain.CarMessage;
import com.muyu.car.service.CarMessageService;
import com.muyu.common.core.domain.Result;
import io.swagger.v3.oas.annotations.Operation;
import io.swagger.v3.oas.annotations.tags.Tag;
import lombok.extern.log4j.Log4j2;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.*;

import javax.annotation.Resource;
import java.util.List;

@Log4j2
@RestController
@RequestMapping("/carMessage")
@Tag(name = "信息报文模块" )
public class CarMessageController {
    @Resource
    private CarMessageService carMessageService;
    /**
     * 根据所属车类别 解析 车辆报文模板
     * @param
     * @return
     */
    @PostMapping("/selectCarMessageList")
    @Operation(summary = "报文模板展示列表")
    public Result<List<CarMessage>> selectCarMessageList(Integer carMessageCartype){
        List<CarMessage> carMessages = carMessageService.selectCarMessageList(carMessageCartype);
        return Result.success(carMessages);
    }


    /**
     * 添加车辆报文规则
     */
    @PostMapping("/insertCarMessage")
    @Operation(summary = "添加报文信息")
    public Result insertCarMessage(@Validated @RequestBody CarMessage carMessage){
        Result carMessage1 = carMessageService.insertCarMessage(carMessage);
        return Result.success(carMessage1);
    }

    /**
     * 删除车辆报文规则
     *
     */
    @PostMapping("/delectByCarMessageId")
    @Operation(summary = "删除报文信息")
    public Result delectByCarMessageId(Integer carMessageId){
        Result carMessage1 = carMessageService.delectByCarMessageId(carMessageId);
        return Result.success(carMessage1);
    }

    /**
     * 修改车辆报文规则
     */
    @PostMapping("/updateCarMessage")
    @Operation(summary = "修改报文信息")
    public Result updateCarMessage(@Validated @RequestBody CarMessage carMessage){
        Result updateCarMessage = carMessageService.updateCarMessage(carMessage);
        return Result.success(updateCarMessage,"修改成功");
    }

    /**
     * 测试分割字符
     */
    @PostMapping("/inciseCarMessage")
    @Operation(summary = "解析报文处理", description = "解析报文测试")
    public Result<JSONObject> inciseCarMessage(@RequestParam(name = "testString") String testString){
        JSONObject carMessage = carMessageService.inciseCarMessage(testString);
        return Result.success(carMessage);

    }

    /**
     * 测试分割字符
     */





}
