package com.muyu.car.service.Impl;

import com.alibaba.fastjson.JSON;
import com.alibaba.fastjson.JSONObject;
import com.fasterxml.jackson.core.JsonProcessingException;
import com.muyu.car.domain.CarInformation;
import com.muyu.car.domain.CarMessage;
import com.muyu.car.mapper.CarInformationMapper;
import com.muyu.car.mapper.CarMessageMapper;
import com.muyu.car.service.CarMessageService;
import com.muyu.common.core.domain.Result;
import lombok.extern.log4j.Log4j2;
import org.springframework.data.redis.core.RedisTemplate;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;
import java.util.ArrayList;
import java.util.Collection;
import java.util.List;
import java.util.Objects;

@Service
@Log4j2
public class CarMessageServiceImpl implements CarMessageService {
    @Resource
    private CarMessageMapper carMessageMapper;
    @Resource
    private CarInformationMapper carInformationMapper;

    @Resource
    private RedisTemplate<String, Objects> redisTemplate;


    @Override
    public List<CarMessage> selectCarMessageList(Integer carMessageCartype) {
        return  carMessageMapper.selectCarMessageList(carMessageCartype);
    }

    @Override
    public Result insertCarMessage(CarMessage carMessage) {
        Integer inserted = carMessageMapper.insertCarMessage(carMessage);
        if (inserted > 0){
            return Result.success(inserted,"添加成功");
        }
        return Result.error(402,"添加失败");
    }

    @Override
    public Result delectByCarMessageId(Integer carMessageId) {
        Integer deleteByCarMessageId = carMessageMapper.deleteByCarMessageId(carMessageId);
        if (deleteByCarMessageId >0){
            return Result.success(carMessageId ,"删除成功");
        }
        return  Result.error(402,"删除失败");
    }

    @Override
    public Result updateCarMessage(CarMessage carMessage) {
        Integer integer = carMessageMapper.updateCarMessage(carMessage);
        if(integer > 0)
        {
            return Result.success(carMessage,"修改成功");
        }
        return Result.error( 402,"修改失败");
    }


    @Override
    public JSONObject inciseCarMessage(String testString) {
        //根据空格拆分切割数据字符串
        String[] split = testString.split(" ");
        StringBuilder stringBuilder = new StringBuilder();
        for (String conversion : split) {
            //将16进制字符串转换为对应的10进制
            int inciseindex = Integer.parseInt(conversion, 16);
            // 将10进制转换为对应的字符
            stringBuilder.append((char) inciseindex);
        }
        //切取车辆VIN
        String substring = stringBuilder.substring(0, 17);
        log.info("车辆的VIN码:" + substring);
       //根据给定的vehicleVin（车辆VIN号）获取对应的模板车辆分类carMessageCartype
        Long selectcared = carMessageMapper.selectcarMessageCartype(substring);
        //根据给定的vehicleVin（车辆VIN号）获取对应的模板信息
     //   List<CarInformation> carInformations = carMessageMapper.selectcarInformationType(substring);
        //创建接受数据的数组
        List<CarMessage> carMessagesList ;

               try{
            String redisKey = "carMessageList" + selectcared;
             if (redisTemplate.hasKey(redisKey)){
            List<Objects> list = redisTemplate.opsForList().range(redisKey ,  0, -1);
                 carMessagesList =
                         list.stream().map(objects ->
                         JSON.parseObject(objects.toString(), CarMessage.class))
                         .toList();
                 log.info("Redis缓存查询成功");
              }else {
                     carMessagesList  = carMessageMapper.selectCarMessageList(Math.toIntExact(selectcared));

                     carMessagesList.forEach(
                             listReq -> redisTemplate.opsForList().rightPushAll(redisKey, (Collection<Objects>) listReq)
                     );
                 log.info("数据库查询成功");
        }
             log.info("获取失败,请重试");
        }catch(Exception e){
        throw  new RuntimeException("获取报文模板失败");
    }
    //判断报文模板 列表 不为空
        if(carMessagesList.isEmpty()){
            throw new RuntimeException("报文模版为空");
        }
    //存储报文模板解析后的数据
        JSONObject jsonObject = new JSONObject();
        for (CarMessage carMessage : carMessagesList) {
            //起始位下标
            Integer startIndex = carMessage.getCarMessageStartIndex();
            //结束位下标
            Integer endIndex = carMessage.getCarMessageEndIndex();
            //根据报文模板获取保温截取位置
            String value = stringBuilder.substring(startIndex, endIndex);
            //存入数据
            jsonObject.put(carMessage.getMessageTypeName(), value);

        }
        return jsonObject;
    }



}
